==> nextcloud-31.0.7-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/files_downloadlimit/l10n/ga.js <==
OC.L10N.register(
    "files_downloadlimit",
    {
    "Files download limit" : "Teorainn a íoslódáil comhaid",
    "File link share download limit" : "Teorainn íoslódála nasc comhaid",
    "This app allows limiting the number of downloads for external link shares." : "Ligeann an aip seo teorainn a chur le líon na n-íoslódálacha le haghaidh scaireanna naisc sheachtracha.",
    "The minimum limit is 1" : "Is é 1 an teorainn íosta",
    "Failed to set download limit" : "Theip ar an teorainn íoslódála a shocrú",
    "Failed to remove download limit" : "Theip ar an teorainn íoslódála a bhaint",
    "Limit downloads" : "Teorainneacha íoslódáil",
    "Set download limit" : "Socraigh teorainn íoslódáil",
    "Setting a new limit will reset the download count" : "Má shocraítear teorainn nua, athshocrófar an comhaireamh íoslódála",
    "_1 remaining download allowed_::_{count} remaining downloads allowed_" : ["1 íoslódáil fágtha ceadaithe","{count} íosluchtú fágtha ceadaithe","{count} íosluchtú fágtha ceadaithe","{count} íosluchtú fágtha ceadaithe","{count} íosluchtú fágtha ceadaithe"],
    "Failed to set default download limit" : "Theip ar an teorainn íoslódála réamhshocraithe a shocrú",
    "Download limit" : "Teorainn a íoslódáil",
    "Configure the default download limit for external shares." : "Cumraigh an teorainn íoslódála réamhshocraithe do scaireanna seachtracha.",
    "Set default download limit" : "Socraigh teorainn íoslódála réamhshocraithe",
    "You have reached the maximum amount of downloads allowed" : "Tá an t-uasmhéid íoslódálacha ceadaithe agat",
    "This share has a limited number of downloads. Are you sure you want to trigger a new download?" : "Tá líon teoranta íoslódálacha ag an sciar seo. An bhfuil tú cinnte gur mhaith leat íosluchtú nua a spreagadh?"
},
"nplurals=5; plural=(n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4);");

==> nextcloud-32.0.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/files_downloadlimit/l10n/ga.js <==
OC.L10N.register(
    "files_downloadlimit",
    {
    "Files download limit" : "Teorainn a íoslódáil comhaid",
    "File link share download limit" : "Teorainn íoslódála nasc comhaid",
    "This app allows limiting the number of downloads for external link shares." : "Ligeann an aip seo teorainn a chur le líon na n-íoslódálacha le haghaidh scaireanna naisc sheachtracha.",
    "The minimum limit is 1" : "Is é 1 an teorainn íosta",
    "Failed to set download limit" : "Theip ar an teorainn íoslódála a shocrú",
    "Failed to remove download limit" : "Theip ar an teorainn íoslódála a bhaint",
    "Limit downloads" : "Teorainneacha íoslódáil",
    "Set download limit" : "Socraigh teorainn íoslódáil",
    "Setting a new limit will reset the download count" : "Má shocraítear teorainn nua, athshocrófar an comhaireamh íoslódála",
    "_1 remaining download allowed_::_{count} remaining downloads allowed_" : ["1 íoslódáil fágtha ceadaithe","{count} íosluchtú fágtha ceadaithe","{count} íosluchtú fágtha ceadaithe","{count} íosluchtú fágtha ceadaithe","{count} íosluchtú fágtha ceadaithe"],
    "Download limit" : "Teorainn a íoslódáil",
    "Configure the default download limit for external shares." : "Cumraigh an teorainn íoslódála réamhshocraithe do scaireanna seachtracha.",
    "Set default download limit" : "Socraigh teorainn íoslódála réamhshocraithe",
    "You have reached the maximum amount of downloads allowed" : "Tá an t-uasmhéid íoslódálacha ceadaithe agat",
    "This share has a limited number of downloads. Are you sure you want to trigger a new download?" : "Tá líon teoranta íoslódálacha ag an sciar seo. An bhfuil tú cinnte gur mhaith leat íosluchtú nua a spreagadh?",
    "Failed to set default download limit" : "Theip ar an teorainn íoslódála réamhshocraithe a shocrú"
},
"nplurals=5; plural=(n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4);");
